Form

Enum Form 

pub enum Form {
    State,
    Slots,
    Items,
    Arguments,
    Argument,
}
How an object is created from the value it’s emitted as.

The deserializer attaches the form to the first event of an object together with its class (see take_form). The serializer creates objects in this form (see set_form) which makes them read back as they were. Without a form, objects that are maps are created from their state, lists from their items, tuples from their arguments and other values are the argument.

Variants



State

The value is the state: cls.__new__(cls) and __setstate__ (or the attributes for maps). This is how Python pickles instances of classes (including dataclasses).



Slots

The value is the state of an object with slots: cls.__new__(cls) and the entries of the map are set as attributes.



Items

The value is the items: cls.__new__(cls) and __setitem__ for maps, extend (or append) for sequences. This is how Python pickles subclasses of dict and list.



Arguments

The value is the arguments: cls(*value) for sequences and cls.__new__(cls, **value) for maps (which requires protocol 4).



Argument

The value is the only argument: cls(value).