pub struct Object<T> {
pub class: Option<Global>,
pub form: Option<Form>,
pub value: T,
}Expand description
A value with the class of a Python object.
When deserialized the class of the value (if there is one) is captured, when serialized the value is written as an object of the class:
use std::collections::BTreeMap;
use deser_pickle::{Global, Object};
// a `Point(x=1, y=2)` of a module `geometry`
let input = b"\x80\x04\x95*\x00\x00\x00\x00\x00\x00\x00\x8c\x08geometry\x94\x8c\x05Point\x94\x93\x94)\x81\x94}\x94(\x8c\x01x\x94K\x01\x8c\x01y\x94K\x02ub.";
let point: Object<BTreeMap<String, i32>> = deser_pickle::from_slice(input).unwrap();
assert_eq!(point.class, Some(Global::new("geometry", "Point")));
assert_eq!(point.value["y"], 2);Other formats do not have classes. When deserializing from such
formats, the class is None, when serializing it’s ignored.
Fields
class: Option<Global>The class of the value.
form: Option<Form>How the object is created from the value (see Form).
value: TThe value.
Implementations