pub struct Reference { /* private fields */ }Expand description
A reference to a value that contains it (a cycle).
Pickles are graphs: a value can be reached more than once and can
contain itself. Values that are reached more than once are emitted at
every place (see References), with an id as event
data (see take_shared_id). Where a value is reached again from
within itself it cannot be emitted again, a reference with the id of the
value is emitted instead.
The fallback of the extension is null: types that do not understand
references see them as missing values (an Option is None).
use deser_pickle::Reference;
// `x = []; x.append(x)`
let input = b"\x80\x04\x95\x06\x00\x00\x00\x00\x00\x00\x00]\x94h\x00a.";
let value: Vec<Reference> = deser_pickle::from_slice(input).unwrap();
assert_eq!(value.len(), 1);
let value: Vec<Option<u32>> = deser_pickle::from_slice(input).unwrap();
assert_eq!(value, [None]);Implementations